@@ -115,22 +115,27 @@ ebBHF <- function(formula,dom,selectdom,Xnonsample,MC=100,data,transform="BoxCox
    ys       <- bxcx(welfaret,lambda=lambda,type=transform)
 
    # Fit the nested-error model to sample data by REML method using function lme from library nlme. 
-   fit.EB<-lme(ys~-1+Xs,random=~1|as.factor(dom),method="REML")
-
+   #fit.EB<-lme(ys~-1+Xs,random=~1|as.factor(dom),method="REML")
+   fit.EB<-lmer(ys~-1+Xs+(1|dom),REML=TRUE)
+   
    # Save some of the results of the fitting method in variables
-   betaest   <-matrix(fixed.effects(fit.EB),nrow=p,ncol=1) # Vector of model coefficients (size p)
-   upred     <-random.effects(fit.EB)                  # Predicted random effects: Watch out! It is not a vector, it is a matrix with 1 column
-   sigmae2est<-fit.EB$sigma^2                          # Estimated error variance
-   sigmau2est<-as.numeric(VarCorr(fit.EB)[1,1])        # VarCorr(fit2) is the estimated cov. matrix of the model random components
-   sqrtsigmae2est<-sqrt(sigmae2est)
+   betaest   <-matrix(fixef(fit.EB),nrow=p,ncol=1) # Vector of model coefficients (size p)
+   upred     <-ranef(fit.EB)$dom                  # Predicted random effects: Watch out! It is not a vector, it is a matrix with 1 column
+   #sigmae2est<-fit.EB$sigma^2                          # Estimated error variance
+   #sigmau2est<-as.numeric(VarCorr(fit.EB)[1,1])        # VarCorr(fit2) is the estimated cov. matrix of the model random components
+   #sqrtsigmae2est<-sqrt(sigmae2est)
 
+   sigmae2est<-summary(fit.EB)$sigma^2
+   sigmau2est<-as.numeric(VarCorr(fit.EB))
+   sqrtsigmae2est<-sqrt(sigmae2est)
+   
    # Create a list object containing different results from the model fit.
-   Resultsfit<-list(summary=summary(fit.EB),fixed=fixed.effects(fit.EB),
+   Resultsfit<-list(summary=summary(fit.EB),fixed=fixef(fit.EB),
                     random=upred,
                     errorvar=sigmae2est,
                     refvar=sigmau2est,
-                    loglike=fit.EB$logLik,
-                    residuals=fit.EB$residuals[1:n])
+                    loglike=logLik(fit.EB)[1],
+                    residuals=as.vector(residuals(fit.EB)))
 
 
    # EB method starts: Generate MC vectors of non-sample values of the response 
